@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 $|++;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # Regex to match balanced params. Reproduced from Regexp::Common to avoid
 # adding a non-core dependency.
@@ -33,11 +33,11 @@ sub emit_placeholder {
     my ( $self, $subname, $brace, $clauses ) = @_;
 
     # Store the signature and returns() for later use
-    my $id = $self->{counter}++;
+    my $id = sprintf "%03d", $self->{counter}++;
     $self->{store_clause}->{$id} = $clauses;
     $self->{store_sub}->{$id}    = $subname;
 
-    # Turns 'my_method_name' into 'SUB4ethod_name'
+    # Turns 'my_method_name' into 'SUB004hod_name'
     my $marker = $self->marker . $id;
     substr( $subname, 0, length($marker), $marker );
 
@@ -55,14 +55,17 @@ sub emit_keyword {
     # Combine clauses (parameter list, returns(), etc) into a string separate
     # each with a space and lead with a space if there are any
     my $clause = join ' ', grep { length $_ } @$clauses;
+
+    # FIXME: This forces space between sub/func/method name and clauses list
+    # (ignores perltidy settings)
     $clause = ' ' . $clause if length $clause;
 
     return sprintf '%s %s%s%s', $self->keyword, $subname, $clause, $brace;
 }
 
 sub emit_csc {
-    my ( $self, $id ) = @_;
-    return sprintf "## tidy end: %s %s", $self->keyword, $self->{store_sub}->{$_};
+    my ( $self, $id, $cscp ) = @_;
+    return sprintf "%s %s %s", $cscp, $self->keyword, $self->{store_sub}->{$_};
 }
 
 sub clauses {
@@ -116,7 +119,7 @@ sub prefilter {
 }
 
 sub postfilter {
-    my ( $self, $code ) = @_;
+    my ( $self, $code, $args ) = @_;
     my $marker      = $self->marker;
     my $replacement = $self->replacement;
     my $subname     = $self->identifier;
@@ -127,7 +130,7 @@ sub postfilter {
         ^\s*\K                     # preserve leading whitespace
         $replacement          \s+  # keyword was converted to sub/package
         $marker                    #
-        (?<id> \d+)                # the identifier
+        (?<id> \d\d\d)             # the identifier
         [\w:]* \b                  # the rest of the orignal sub/package name
         (?<newline> \n? \s* )      # possible newline and indentation
         (?<brace>   .*?     ) [ ]* # opening brace on followed orig comments
@@ -138,10 +141,11 @@ sub postfilter {
     }egmx;
 
     # Restore the orig sub name when inserted via the -csc flag
+    my $cscp = $args->{'-cscp'} || '## end';
     $code =~ s{
-        \#\# \s tidy \s end: \s sub \s ${marker} $_
+        \Q${cscp}\E \s sub \s ${marker} $_
     }{
-        $self->emit_csc( $_ );
+        $self->emit_csc( $_, $cscp );
     }egx for @ids;
 
     return $code;
@@ -159,7 +163,7 @@ Perl::Tidy::Sweetened::Keyword::Block - Perl::Tidy::Sweetened filter plugin to d
 
 =head1 VERSION
 
-version 1.16
+version 1.17
 
 =head1 SYNOPSIS
 
@@ -246,7 +250,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Mark Grimes E<lt>mgrimes@cpan.orgE<gt>.
+This software is copyright (c) 2021 by Mark Grimes E<lt>mgrimes@cpan.orgE<gt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
