@@ -5,7 +5,7 @@ package Perl::Tidy::Sweetened::Pluggable;
 use strict;
 use warnings;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 sub new {
     my ( $class, %args ) = @_;
@@ -14,6 +14,8 @@ sub new {
 
 sub filters { return ( $_[0]->{filters} ||= [] ) }
 
+sub args { return ( $_[0]->{args} ||= {} ) }
+
 sub add_filter {
     my $self = shift;
     push @{ $self->filters }, @_;
@@ -22,7 +24,7 @@ sub add_filter {
 sub prefilter {
     my ( $self, $code ) = @_;
     for my $filter ( @{ $self->filters } ) {
-        $code = $filter->prefilter($code);
+        $code = $filter->prefilter($code, $self->args);
     }
 
     # warn "After prefilter, before tidy\n";
@@ -38,11 +40,18 @@ sub postfilter {
     # warn $code;
 
     for my $filter ( @{ $self->filters } ) {
-        $code = $filter->postfilter($code);
+        $code = $filter->postfilter($code, $self->args);
     }
     return $code;
 }
 
+sub add_args {
+    my ( $self,       $args ) = @_;
+    my ( $body_parts, $msg )  = Perl::Tidy::parse_args($args);
+    $self->{args} =
+      { map { my ( $k, $v ) = split /=/, $_, 2; ( $k => $v ) } @$body_parts };
+}
+
 1;
 
 __END__
@@ -55,7 +64,7 @@ Perl::Tidy::Sweetened::Pluggable - Simple object to facilitate a pluggable filte
 
 =head1 VERSION
 
-version 1.16
+version 1.17
 
 =head1 SYNOPSIS
 
@@ -92,7 +101,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Mark Grimes E<lt>mgrimes@cpan.orgE<gt>.
+This software is copyright (c) 2021 by Mark Grimes E<lt>mgrimes@cpan.orgE<gt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
